@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.61 2006/06/05 15:52:01 evertonm Exp $ */
+/* $Id: client.c,v 1.63 2006/06/07 15:27:43 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -688,7 +688,7 @@ static void tcp_pipe_start(int sd)
                                 session->tv_duration,
                                 on_tcp_duration, pipe);
 
-  nepim_sock_show_opt(stderr, sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
 
   schedule_stat_interval(sd);
 
@@ -791,7 +791,7 @@ static void tcp_pipe_stop(int sd)
 
   nepim_pipe_set_del(&pipes, sd);
 
-  nepim_sock_show_opt(stderr, sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
 }
 
 static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
@@ -897,7 +897,8 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
 
     nodelay = (nepim_global.nagle == -1) ? -1 : !nepim_global.nagle;
 
-    sd = nepim_connect_client_socket(bindaddr, bindaddr_len,
+    sd = nepim_connect_client_socket(nepim_global.verbose_stderr,
+				     bindaddr, bindaddr_len,
 				     ai->ai_addr, ai->ai_addrlen,
                                      ai->ai_family, ai->ai_socktype, 
                                      ai->ai_protocol,
