@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.59 2006/06/07 13:42:38 evertonm Exp $
+  $Id: main.c,v 1.61 2006/06/12 14:58:32 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -423,7 +423,7 @@ int main(int argc, const char *argv[])
                 nepim_global.prog_name);
         exit(1);
       }
-      nepim_global.test_duration = atoi(argv[i]);
+      nepim_global.test_duration = nepim_time_unit(argv[i]);
       continue;
     }
 
@@ -626,7 +626,7 @@ int main(int argc, const char *argv[])
                 nepim_global.prog_name);
         exit(1);
       }
-      nepim_global.bit_rate = strtoll(argv[i], 0, 10);
+      nepim_global.bit_rate = nepim_unit_ll(argv[i]);
       bytes = nepim_bps2bytes(nepim_global.bit_rate,
                               nepim_global.write_delay);
       if (bytes < 1) {
@@ -649,7 +649,7 @@ int main(int argc, const char *argv[])
                 nepim_global.prog_name);
         exit(1);
       }
-      nepim_global.pkt_rate = atoi(argv[i]);
+      nepim_global.pkt_rate = nepim_unit_int(argv[i]);
       pkts = nepim_pps2packets(nepim_global.pkt_rate,
                                nepim_global.write_delay);
       if (pkts < 1) {
@@ -671,7 +671,7 @@ int main(int argc, const char *argv[])
                 nepim_global.prog_name);
         exit(1);
       }
-      nepim_global.pkt_rate = atoi(argv[i]);
+      nepim_global.pkt_rate = nepim_unit_int(argv[i]);
 
       if (nepim_global.pkt_rate < 1) {
         fprintf(stderr, "%s: excessively low send-rate: %d pps (min: 1 pps)\n",
