@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.73 2006/06/05 15:52:01 evertonm Exp $ */
+/* $Id: server.c,v 1.75 2006/06/07 15:27:43 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -457,12 +457,13 @@ static int parse_greetings(int sd,
       return 1;
     }
 
-  if (nepim_socket_keepalive(sd, opt.socket_keepalive))
+  if (nepim_socket_keepalive(nepim_global.verbose_stderr, sd, opt.socket_keepalive))
     return 1;
 
   nodelay = (opt.nagle == -1) ? -1 : !opt.nagle;
 
-  result = nepim_socket_tcp_opt(sockaddr_family, sd, nodelay);
+  result = nepim_socket_tcp_opt(nepim_global.verbose_stderr,
+				sockaddr_family, sd, nodelay);
   if (result) {
     fprintf(stderr, 
             "%d: %s: %s: could not set tcp options: %d\n",
@@ -729,7 +730,7 @@ static void tcp_pipe_start(int sd)
                                 session->tv_duration,
                                 on_tcp_duration, pipe);
 
-  nepim_sock_show_opt(stderr, sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
 
   schedule_stat_interval(sd);
 
@@ -849,7 +850,7 @@ static void tcp_pipe_kill(int sd)
   tcp_pipe_cancel_timers(sd);
   tcp_pipe_cancel_io(sd);
 
-  nepim_sock_show_opt(stderr, sd);
+  nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
 
   if (close(sd))
     fprintf(stderr, "%d: close failed\n", sd);
@@ -908,7 +909,8 @@ static void *on_tcp_connect(oop_source *src, int sd,
     }
   }
 
-  result = nepim_socket_opt(conn_sd, nepim_global.pmtu_mode, 
+  result = nepim_socket_opt(nepim_global.verbose_stderr,
+			    conn_sd, nepim_global.pmtu_mode, 
                             nepim_global.ttl, nepim_global.tos);
   if (result) {
     fprintf(stderr, 
@@ -990,7 +992,8 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
     nepim_sock_dump_addr(addr_str, sizeof addr_str,
 			 ai->ai_addr, ai->ai_addrlen);
 
-    sd = nepim_create_listener_socket(ai->ai_addr, ai->ai_addrlen,
+    sd = nepim_create_listener_socket(nepim_global.verbose_stderr,
+				      ai->ai_addr, ai->ai_addrlen,
                                       ai->ai_family, ai->ai_socktype, 
                                       ai->ai_protocol,
                                       nepim_global.listen_backlog,
@@ -1046,7 +1049,8 @@ static int spawn_unix_listener(const char *path)
   
   nodelay = (nepim_global.nagle == -1) ? -1 : !nepim_global.nagle;
 
-  sd = nepim_create_listener_socket((struct sockaddr *) &un_sock_addr, 
+  sd = nepim_create_listener_socket(nepim_global.verbose_stderr,
+				    (struct sockaddr *) &un_sock_addr, 
 				    sizeof(un_sock_addr),
 				    AF_UNIX,
 				    SOCK_STREAM, 
