@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: session.h,v 1.19 2006/04/23 06:33:46 evertonm Exp $ */
+/* $Id: session.h,v 1.22 2006/06/02 14:24:38 evertonm Exp $ */
 
 #ifndef NEPIM_SESSION_H
 #define NEPIM_SESSION_H
@@ -69,6 +69,12 @@ struct nepim_session_t {
   unsigned char fill_byte;
   int pause_duration;
   int overhead;                /* bytes */
+  int sweep_random;            /* boolean */
+  int sweep_step;              /* bytes */
+  int write_floor;             /* bytes */
+  int write_ceil;              /* bytes */
+
+  int write_sweep_current;     /* bytes */
 
   int rate_remaining;          /* bytes, used when max_bit_rate > 0 */
   int pkt_remaining;           /* pkts, used when max_pkt_rate > 0 */
@@ -100,5 +106,7 @@ void nepim_session_init(nepim_session_t *session, const nepim_greet_t *opt,
 void nepim_session_write_add(nepim_session_t *session, int len);
 void nepim_session_read_add(nepim_session_t *session, int len);
 
+int nepim_write_sweep(nepim_session_t *session);
+
 #endif /* NEPIM_SESSION_H */
 
